====
xirr
====

Irregular internal rate of return (xirr) and net present value (npv) calculations.

Based on https://stackoverflow.com/questions/8919718/financial-python-library-that-has-xirr-and-xnpv-function
with some ideas for handling special cases from https://github.com/RayDeCampo/java-xirr/


Contents
========

.. toctree::
   :maxdepth: 2

   Installation <installation>
   License <license>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
